@@ -12,11 +12,11 @@ module Network.HTTP.Link (
 
 import           Control.Error.Util (hush)
 import           Data.Text (Text, pack)
-import           Data.Text.Encoding
+import           Data.Text.Encoding (encodeUtf8)
 import safe      Network.HTTP.Link.Parser
 import safe      Network.HTTP.Link.Types
 import safe      Network.HTTP.Link.Writer
-import           Web.HttpApiData
+import           Web.HttpApiData (ToHttpApiData(..))
 
 instance (IsURI uri) ⇒ ToHttpApiData [Link uri] where
   toUrlPiece = toUrlPiece . writeLinkHeader
