@@ -3,8 +3,8 @@
 -- | The data type definitions for the HTTP Link header.
 module Network.HTTP.Link.Types where
 
-import           Data.Text
-import           Network.URI
+import           Data.Text (Text, pack, unpack)
+import           Network.URI (URI, parseURIReference)
 
 -- | The link attribute key.
 data LinkParam = Rel | Anchor | Rev | Hreflang | Media | Title | Title' | ContentType | Other Text
