@@ -9,7 +9,7 @@ import           Data.Text hiding (map)
 #if !MIN_VERSION_base(4,8,0)
 import           Data.Monoid (mconcat)
 #endif
-import           Network.URI
+import           Network.URI (escapeURIString)
 import           Network.HTTP.Link.Types
 
 writeParamKey ∷ LinkParam → Text
